@@ -1,7 +1,7 @@
 #ifndef WINGs_DND
 #define WINGs_DND
 
-#include <WINGs.h>
+#include <WINGs/WINGs.h>
 
 void DndInitialize(WMWidget *w);
 
