@@ -7,7 +7,7 @@
  *****************************************************************************/
 
 #include <WMaker.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
