@@ -4,7 +4,7 @@
 #include <X11/Xutil.h>
 #include <X11/Xproto.h>
 #include <WMaker.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include <X11/Xlocale.h>
 #include <X11/keysym.h>
 #include <sys/stat.h>
@@ -245,7 +245,7 @@ FSFileView *
 FSCreateFileView(FSViewer *fsViewer, char *path, Bool primary)
 {
     int                   divThickness;
-    proplist_t array      = NULL;
+    WMPropList* array      = NULL;
     FSFileView           *fView;
     GNUstepWMAttributes   attributes;
 
@@ -397,10 +397,10 @@ FSCreateFileView(FSViewer *fsViewer, char *path, Bool primary)
     if ((fView->primary))
     {
 	memset((void *) &attributes, 0, sizeof(GNUstepWMAttributes));
-	attributes.window_style = (NSTitledWindowMask |
-				   NSMiniaturizableWindowMask | 
-				   NSResizableWindowMask);
-	attributes.window_level = NSNormalWindowLevel;
+	attributes.window_style = (WMTitledWindowMask |
+				   WMMiniaturizableWindowMask | 
+				   WMResizableWindowMask);
+	attributes.window_level = WMNormalWindowLevel;
 	attributes.extra_flags = GSFullKeyboardEventsFlag;
 	attributes.flags = (GSWindowStyleAttr | GSWindowLevelAttr |
 			    GSExtraFlagsAttr);
@@ -444,13 +444,13 @@ FSCreateFileView(FSViewer *fsViewer, char *path, Bool primary)
                               WMViewSizeDidChangeNotification,
                               WMWidgetView(fView->fileBrowserF));
 
-    WMSetWindowMiniwindowImage(fView->fileView, 
-			       WMGetApplicationIconImage(fView->scr));
+    WMSetWindowMiniwindowPixmap(fView->fileView, 
+			       WMGetApplicationIconPixmap(fView->scr));
 
     array = WMGetUDObjectForKey(defaultsDB, "SHELF");
-    if(array && PLIsArray(array))
+    if(array && WMIsPLArray(array))
     {
-	fView->shelf = PLDeepCopy(array);
+	fView->shelf = WMDeepCopyPropList(array);
     }
 
     FSUpdateFileViewTitles(fView);
@@ -951,19 +951,19 @@ FSAddFileViewShelfItemIntoProplist(FSFileView *fView, FileInfo *fileInfo)
 {
     Bool        notFound;
     char       *pathname = NULL;
-    proplist_t  val      = NULL;
-    proplist_t  array    = NULL;
+    WMPropList*  val      = NULL;
+    WMPropList*  array    = NULL;
 
     /*
      * Get the Shelf entry and insert the pathname into
      * the array
      */
     pathname = GetPathnameFromPathName(fileInfo->path, fileInfo->name);
-    val = PLMakeString(pathname);
+    val = WMCreatePLString(pathname);
     array = WMGetUDObjectForKey(defaultsDB, "SHELF");
     if (!array)
     {
-	array = PLMakeArrayFromElements( PLMakeString(wgethomedir()), NULL );
+	array = WMCreatePLArray( WMCreatePLString(wgethomedir()), NULL );
 	WMSetUDObjectForKey(defaultsDB, array, "SHELF");
     }	
     notFound = InsertArrayElement(array, val);
@@ -977,8 +977,8 @@ FSAddFileViewShelfItemIntoProplist(FSFileView *fView, FileInfo *fileInfo)
     {
 	WMSetUDObjectForKey(defaultsDB, array, "SHELF");
 	
-	PLRelease(fView->shelf);
-	fView->shelf = PLDeepCopy(array);
+	WMReleasePropList(fView->shelf);
+	fView->shelf = WMDeepCopyPropList(array);
     }
 
     if(pathname)
@@ -994,9 +994,9 @@ static void
 FSRemoveFileViewItemFromShelf(FSFileView *fView, FSFileIcon *fileIcon)
 {
     char       *pathname = NULL;
-    proplist_t  key      = NULL;
-    proplist_t  val      = NULL;
-    proplist_t  array    = NULL;
+    WMPropList*  key      = NULL;
+    WMPropList*  val      = NULL;
+    WMPropList*  array    = NULL;
     FileInfo   *fileInfo = NULL;
     FSFileIcon *tmp = fView->fileIcons;
 
@@ -1033,23 +1033,23 @@ FSRemoveFileViewItemFromShelf(FSFileView *fView, FSFileIcon *fileIcon)
     
     fileInfo = FSGetFileButtonFileInfo(fileIcon->btn);
     pathname = GetPathnameFromPathName(fileInfo->path, fileInfo->name);
-    val = PLMakeString(pathname);
+    val = WMCreatePLString(pathname);
     array = WMGetUDObjectForKey(defaultsDB, "SHELF");
 
-    if (array && PLIsArray(array))
+    if (array && WMIsPLArray(array))
     {
 	FSRemoveArrayElement(array, val);	    
     }
     WMSetUDObjectForKey(defaultsDB, array, "SHELF");
 
-    PLRelease(fView->shelf);
-    fView->shelf = PLDeepCopy(array);
+    WMReleasePropList(fView->shelf);
+    fView->shelf = WMDeepCopyPropList(array);
 
     FSReorganiseShelf(fView);
     fView->dirtyFileIcon = fileIcon;
     
     if(key)
-	PLRelease(key);
+	WMReleasePropList(key);
     if(pathname)
 	free(pathname);
 }
@@ -1061,20 +1061,20 @@ FSRemoveFileViewItemFromShelf(FSFileView *fView, FSFileIcon *fileIcon)
 static void
 FSSetupFileViewShelfItems(FSFileView *fView)
 {
-    proplist_t key     = NULL;
-    proplist_t array   = NULL;
+    WMPropList* key     = NULL;
+    WMPropList* array   = NULL;
 
     array = WMGetUDObjectForKey(defaultsDB, "SHELF");
-    if(array && PLIsArray(array))
+    if(array && WMIsPLArray(array))
     {
 	char *path;
 	FileInfo *fileInfo = NULL;
 	int numElem, i;
 	
-	numElem = PLGetNumberOfElements(array);
+	numElem = WMGetPropListItemCount(array);
 	for(i = 0; i < numElem; i++)
 	{	
-	    path = PLGetString(PLGetArrayElement(array, i));
+	    path = WMGetFromPLString(WMGetFromPLArray(array, i));
 	    fileInfo = FSGetFileInfo(path);
 	    FSAddFileViewShelfItem(fView, fileInfo);
 	}
@@ -1091,8 +1091,8 @@ FSSetupFileViewShelfItems(FSFileView *fView)
 void
 FSUpdateFileViewShelf(FSFileView *fView)
 {
-    proplist_t key     = NULL;
-    proplist_t array   = NULL;
+    WMPropList* key     = NULL;
+    WMPropList* array   = NULL;
     FSFileIcon *tmp    = fView->fileIcons;
 
     /* rid ourselves of the dirty File Icon */
@@ -1105,14 +1105,14 @@ FSUpdateFileViewShelf(FSFileView *fView)
 
     /* get the global array */
     array = WMGetUDObjectForKey(defaultsDB, "SHELF");
-    if(array && PLIsArray(array))
+    if(array && WMIsPLArray(array))
     {
 	char *path;
 	FileInfo *fileInfo = NULL;
 	int numElem, i;
 	
 	/* Check to see if they are different */
-	if(PLIsEqual(array, fView->shelf) == NO)
+	if(WMIsPropListEqualTo(array, fView->shelf) == 0)
 	{
 	    /* they are, so clear the shelf */
 	    while(tmp != NULL)
@@ -1125,16 +1125,16 @@ FSUpdateFileViewShelf(FSFileView *fView)
 	    fView->fileIconCnt = 0;
 	    
 	    /* reload the shelf */
-	    numElem = PLGetNumberOfElements(array);
+	    numElem = WMGetPropListItemCount(array);
 	    for(i = 0; i < numElem; i++)
 	    {	
-		path = PLGetString(PLGetArrayElement(array, i));
+		path = WMGetFromPLString(WMGetFromPLArray(array, i));
 		fileInfo = FSGetFileInfo(path);
 		FSAddFileViewShelfItem(fView, fileInfo);
 	    }
 	    
-	    PLRelease(fView->shelf);
-	    fView->shelf = PLDeepCopy(array);
+	    WMReleasePropList(fView->shelf);
+	    fView->shelf = WMDeepCopyPropList(array);
 	}
     }
 }
