@@ -1,4 +1,4 @@
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 
 #include "files.h"
 #include "FSFileButton.h"
@@ -775,8 +775,8 @@ FSAddDisksMenu(FSViewer *fsViewer, WMMenu *menu)
 {
     WMMenu *submenu = NULL;
     char *cmd = NULL;
-    proplist_t devArray = NULL;
-    proplist_t array    = NULL;
+    WMPropList* devArray = NULL;
+    WMPropList* array    = NULL;
 
 /*     devArray = FSGetArrayForNameKey("DISKS", "devices"); */
     devArray = WMGetUDObjectForKey(defaultsDB, "DISCS");
@@ -784,13 +784,13 @@ FSAddDisksMenu(FSViewer *fsViewer, WMMenu *menu)
     if(devArray)
     {
 	int i, numElem;
-	proplist_t tmp;
+	WMPropList* tmp;
 
-	numElem = PLGetNumberOfElements(devArray);
+	numElem = WMGetPropListItemCount(devArray);
 	for(i = 0; i < numElem; i++)
 	{
-	    array = PLGetArrayElement(devArray, i);
-	    if(array && PLIsArray(array))
+	    array = WMGetFromPLArray(devArray, i);
+	    if(array && WMIsPLArray(array))
 	    {
 		Disk *disk = NULL;
 
@@ -798,33 +798,33 @@ FSAddDisksMenu(FSViewer *fsViewer, WMMenu *menu)
 		memset(disk, 0, sizeof(Disk));
 
 		disk->app = fsViewer;
-		tmp = PLGetArrayElement(array, 0);
-		if(PLIsString(tmp))
-		    disk->name = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 0);
+		if(WMIsPLString(tmp))
+		    disk->name = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 1);
-		if(PLIsString(tmp))
-		    disk->point = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 1);
+		if(WMIsPLString(tmp))
+		    disk->point = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 2);
-		if(PLIsString(tmp))
-		    disk->device = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 2);
+		if(WMIsPLString(tmp))
+		    disk->device = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 3);
-		if(PLIsString(tmp))
-		    disk->mntCmd = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 3);
+		if(WMIsPLString(tmp))
+		    disk->mntCmd = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 4);
-		if(PLIsString(tmp))
-		    disk->umntCmd = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 4);
+		if(WMIsPLString(tmp))
+		    disk->umntCmd = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 5);
-		if(PLIsString(tmp))
-		    disk->ejectCmd = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 5);
+		if(WMIsPLString(tmp))
+		    disk->ejectCmd = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 6);
-		if(PLIsString(tmp))
-		    disk->closeCmd = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 6);
+		if(WMIsPLString(tmp))
+		    disk->closeCmd = wstrdup(WMGetFromPLString(tmp));
 		
 		if(disk->name)
 		{
