@@ -2,7 +2,7 @@
 
 #include <X11/Xatom.h>
 #include <X11/keysym.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include "config.h"
 #include "FSViewer.h"
 #include "FSUtils.h"
@@ -624,13 +624,13 @@ short FSRunDestroyConfirm(FSViewer *app, char *file)
     FSSetFSViewerConfirmWindow(app, WMWidgetXID(confirm->win));
     WMMapWidget(confirm->win);
     
-    while (!(confirm->done))
-    {
+/*    while (!(confirm->done))
+    { 
 	XEvent event;
 	
 	WMNextEvent(dpy, &event);
 	WMHandleEvent(&event);
-    }
+    } */
     result = confirm->result;
     
     WMDestroyAlertPanel(confirm);
@@ -1000,11 +1000,11 @@ FSStoreAppInputData(FSAppInputPanel *appInput)
     
     if(extnAdded)
     {
-	proplist_t array = NULL;
+	WMPropList* array = NULL;
 
 	array = WMGetUDObjectForKey(defaultsDB, "EXTN");
-	if(array && PLIsArray(array))
-	    InsertArrayElement(array, PLMakeString(appInput->fileInfo->extn));
+	if(array && WMIsPLArray(array))
+	    InsertArrayElement(array, WMCreatePLString(appInput->fileInfo->extn));
     }
 
     if(appInput->exec)
@@ -1019,121 +1019,6 @@ FSStoreAppInputData(FSAppInputPanel *appInput)
     return exec;
 }
 
-/* static void */
-/* FSStoreAppInputPropListData(FSAppInputPanel *appInput) */
-/* { */
-/*     int  len; */
-/*     char *extn; */
-/*     char *txt; */
-/*     proplist_t dictKey = NULL; */
-/*     proplist_t val     = NULL; */
-/*     proplist_t dict    = NULL; */
-/*     proplist_t key     = NULL; */
-
-    /* Get the contents of the textfileds */
-/*     txt = WMGetTextFieldText(appInput->execField); */
-/*     extn = WMGetTextFieldText(appInput->nameField); */
-
-    /* Update the exec field of the chosen app */
-/*     dictKey = PLMakeString(extn); */
-/*     key = PLMakeString("exec"); */
-/*     val = PLMakeString(txt); */
-
-/*     dict = PLGetDictionaryEntry(filesDB, dictKey); */
-/*     if (dict && PLIsDictionary(dict)) */
-/*     { */
-/* 	proplist_t tmp = NULL; */
-	
-	/* 
-	   Check to make sure the exec field of the app 
-	   doesn't exist. We don't want to overwirte it 
-	   here. This might change in the future. 
-	*/ 
-/* 	tmp = PLGetDictionaryEntry(dict, key); */
-/* 	if(!tmp) */
-/* 	    PLInsertDictionaryEntry(dict, key, val); */
-/*     } */
-/*     else */
-/*     { */
-	/*
-	  The app doesn't exist at all so we can create
-	  a new entry for it in the dictionary 
-	*/ 
-/* 	dict = PLMakeDictionaryFromEntries(key, val, NULL);	 */
-/* 	PLInsertDictionaryEntry(filesDB, dictKey, dict); */
-/*     } */
-
-    /* Add the app to the EXE array if necessary */
-/*     if(key) */
-/* 	PLRelease(key); */
-/*     key = PLMakeString("EXE"); */
-/*     dict = PLGetDictionaryEntry(filesDB, key); */
-/*     if (!dict) */
-/*     { */
-/* 	dict = PLMakeArrayFromElements(NULL, NULL);	 */
-/* 	PLInsertDictionaryEntry(filesDB, key, dict); */
-/*     }	 */
-/*     InsertArrayElement(dict, dictKey); */
-
-/*     if(key) */
-/* 	PLRelease(key); */
-/*     if(val) */
-/* 	PLRelease(val); */
-     
-    /* Set the default viewer for the selected file */
-/*     if( WMGetButtonSelected(appInput->viewBtn) ) */
-/*     { */
-/* 	dictKey = PLMakeString(GetFileExtn(appInput->fileInfo->name)); */
-/* 	key = PLMakeString("viewer"); */
-/* 	val = PLMakeString(extn); */
-	
-/* 	dict = PLGetDictionaryEntry(filesDB, dictKey); */
-/* 	if (!dict) */
-/* 	{ */
-/* 	    dict = PLMakeDictionaryFromEntries(NULL, NULL, NULL);	 */
-/* 	    PLInsertDictionaryEntry(filesDB, dictKey, dict); */
-/* 	} */
-/* 	PLInsertDictionaryEntry(dict, key, val); */
-
-/* 	if(key) */
-/* 	    PLRelease(key); */
-/* 	if(val) */
-/* 	    PLRelease(val); */
-/* 	if(dictKey) */
-/* 	    PLRelease(dictKey); */
-/*     } */
-
-    /* Set the default editor of the selected file */
-/*     if( WMGetButtonSelected(appInput->edBtn) ) */
-/*     { */
-/* 	dictKey = PLMakeString(GetFileExtn(appInput->fileInfo->name)); */
-/* 	key = PLMakeString("editor"); */
-/* 	val = PLMakeString(extn); */
-	    
-/* 	dict = PLGetDictionaryEntry(filesDB, dictKey); */
-/* 	if (!dict) */
-/* 	{ */
-/* 	    dict = PLMakeDictionaryFromEntries(NULL, NULL, NULL);	 */
-/* 	    PLInsertDictionaryEntry(filesDB, dictKey, dict); */
-/* 	} */
-/* 	PLInsertDictionaryEntry(dict, key, val); */
-
-/* 	if(key) */
-/* 	    PLRelease(key); */
-/* 	if(val) */
-/* 	    PLRelease(val); */
-/* 	if(dictKey) */
-/* 	    PLRelease(dictKey); */
-/*     } */
-
-/*     PLSave(filesDB, YES); */
-
-/*     if(extn) */
-/* 	free(extn); */
-/*     if(txt) */
-/* 	free(txt); */
-/* } */
-
 static void
 endedEditingObserver(void *observerData, WMNotification *notification)
 {
@@ -1564,10 +1449,10 @@ FSDestroySelectIconPanel(FSSelectIconPanel *selIcon)
     WMCloseWindow(selIcon->win);
     WMUnmapWidget(selIcon->win);
     WMDestroyWidget(selIcon->win);
-    free((void *) selIcon);
     if(selIcon->iconName)
 	imgStr = wstrdup(selIcon->iconName);
 
+    free((void *) selIcon);
     selIcon = NULL;
 
     return imgStr;
