@@ -1,5 +1,5 @@
 #include <WMaker.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include <math.h> /* for : double rint (double) */
 
 #include "files.h"
