@@ -1,6 +1,6 @@
 #include <X11/Xatom.h>
 #include <X11/keysym.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 
 #include "FSViewer.h"
 #include "FSUtils.h"
@@ -811,8 +811,8 @@ populateTypesTab(FSPreferencesPanel *prefs)
 {
     int numElem, i;
     WMListItem *item   = NULL;
-    proplist_t array   = NULL;
-    proplist_t element = NULL;
+    WMPropList* array   = NULL;
+    WMPropList* element = NULL;
     
     WMClearList(prefs->typesList);
     WMSetTextFieldText(prefs->appsExecTF, "");
@@ -824,17 +824,17 @@ populateTypesTab(FSPreferencesPanel *prefs)
     WMSetButtonImage(prefs->typesIconBtn, NULL);
 
     array = WMGetUDObjectForKey(defaultsDB, "EXTN");
-    if(array && PLIsArray(array))
+    if(array && WMIsPLArray(array))
     {
       
-	numElem = PLGetNumberOfElements(array);
+	numElem = WMGetPropListItemCount(array);
 	for(i = 0; i < numElem; i++)	
 	{
-	    element = PLGetArrayElement(array, i);
+	    element = WMGetFromPLArray(array, i);
 	    
 	    if(element)
 	    {
-		char *str = PLGetDescription(element);
+		char *str = WMGetPropListDescription(element, True);
 
 		if(str)
 		    item = WMAddListItem(prefs->typesList, str);
@@ -843,11 +843,11 @@ populateTypesTab(FSPreferencesPanel *prefs)
 
 		if(item)
 		{
-		    proplist_t tmp = NULL;
+		    WMPropList* tmp = NULL;
 
 		    tmp = WMGetUDObjectForKey(defaultsDB, str);
 		    if(tmp)
-			item->clientData = PLDeepCopy(tmp);
+			item->clientData = WMDeepCopyPropList(tmp);
 		}
 		if(str)
 		    free(str);
@@ -856,16 +856,16 @@ populateTypesTab(FSPreferencesPanel *prefs)
     } 
 
     array = WMGetUDObjectForKey(defaultsDB, "EXE");
-    if(array && PLIsArray(array))
+    if(array && WMIsPLArray(array))
     {
-	numElem = PLGetNumberOfElements(array);
+	numElem = WMGetPropListItemCount(array);
 	for(i = 0; i < numElem; i++)
 	{
-	    element = PLGetArrayElement(array, i);
+	    element = WMGetFromPLArray(array, i);
 	    
 	    if(element)
 	    {
-		char *str = PLGetDescription(element);
+		char *str = WMGetPropListDescription(element, True);
 
 		if(str)
 		    item = WMAddListItem(prefs->appsList, str);
@@ -874,11 +874,11 @@ populateTypesTab(FSPreferencesPanel *prefs)
 
 		if(item)
 		{
-		    proplist_t tmp = NULL;
+		    WMPropList* tmp = NULL;
 
 		    tmp = WMGetUDObjectForKey(defaultsDB, str);
 		    if(tmp)
-			item->clientData = PLDeepCopy(tmp);
+			item->clientData = WMDeepCopyPropList(tmp);
 		}
 		if(str)
 		    free(str);
@@ -890,21 +890,21 @@ populateTypesTab(FSPreferencesPanel *prefs)
 static void
 populateDisksTab(FSPreferencesPanel *prefs)
 {
-    proplist_t devArray = NULL;
-    proplist_t array    = NULL;
+    WMPropList* devArray = NULL;
+    WMPropList* array    = NULL;
 
     devArray = WMGetUDObjectForKey(defaultsDB, "DISCS");
 
-    if(devArray && PLIsArray(devArray))
+    if(devArray && WMIsPLArray(devArray))
     {
 	int i, numElem;
-	proplist_t tmp;
+	WMPropList* tmp;
 
-	numElem = PLGetNumberOfElements(devArray);
+	numElem = WMGetPropListItemCount(devArray);
 	for(i = 0; i < numElem; i++)
 	{
-	    array = PLGetArrayElement(devArray, i);
-	    if(array && PLIsArray(array))
+	    array = WMGetFromPLArray(devArray, i);
+	    if(array && WMIsPLArray(array))
 	    {
 		Disc *disk       = NULL;
 		WMListItem *item = NULL;
@@ -912,10 +912,10 @@ populateDisksTab(FSPreferencesPanel *prefs)
 		disk = (Disc *) wmalloc(sizeof(Disc));
 		memset(disk, 0, sizeof(Disc));
 
-		tmp = PLGetArrayElement(array, 0);
-		if(PLIsString(tmp))
+		tmp = WMGetFromPLArray(array, 0);
+		if(WMIsPLString(tmp))
 		{
-		    disk->name = wstrdup(PLGetString(tmp));
+		    disk->name = wstrdup(WMGetFromPLString(tmp));
 		    item = WMAddListItem(prefs->disksList, disk->name);
 		}
 		else
@@ -923,29 +923,29 @@ populateDisksTab(FSPreferencesPanel *prefs)
 		    continue;
 		}
 
-		tmp = PLGetArrayElement(array, 1);
-		if(PLIsString(tmp))
-		    disk->point = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 1);
+		if(WMIsPLString(tmp))
+		    disk->point = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 2);
-		if(PLIsString(tmp))
-		    disk->device = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 2);
+		if(WMIsPLString(tmp))
+		    disk->device = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 3);
-		if(PLIsString(tmp))
-		    disk->mnt = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 3);
+		if(WMIsPLString(tmp))
+		    disk->mnt = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 4);
-		if(PLIsString(tmp))
-		    disk->umnt = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 4);
+		if(WMIsPLString(tmp))
+		    disk->umnt = wstrdup(WMGetFromPLString(tmp));
 		
-		tmp = PLGetArrayElement(array, 5);
-		if(PLIsString(tmp))
-		    disk->eject = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 5);
+		if(WMIsPLString(tmp))
+		    disk->eject = wstrdup(WMGetFromPLString(tmp));
 	       
-		tmp = PLGetArrayElement(array, 6);
-		if(PLIsString(tmp))
-		    disk->close = wstrdup(PLGetString(tmp));
+		tmp = WMGetFromPLArray(array, 6);
+		if(WMIsPLString(tmp))
+		    disk->close = wstrdup(WMGetFromPLString(tmp));
 
 		if(item)
 		    item->clientData = disk;		
@@ -1001,25 +1001,25 @@ static void
 populateAppsFields(FSPreferencesPanel *prefs)
 {
     char       *str   = NULL;
-    proplist_t  val   = NULL;
+    WMPropList*  val   = NULL;
     WMListItem *item  = WMGetListSelectedItem(prefs->appsList);
 
     if(!item)
 	return;
 
     val = FSGetDBObjectForKey(item->clientData, "exec");
-    if (val && PLIsString(val))
-	WMSetTextFieldText(prefs->appsExecTF, PLGetString(val));
+    if (val && WMIsPLString(val))
+	WMSetTextFieldText(prefs->appsExecTF, WMGetFromPLString(val));
 
     val = FSGetDBObjectForKey(item->clientData, "icon");
-    if (val && PLIsString(val))
+    if (val && WMIsPLString(val))
     {
-	char *img = LocateImage(PLGetString(val));
+	char *img = LocateImage(WMGetFromPLString(val));
 	
 	if(img)
 	{
 	    FSSetButtonImageFromFile(prefs->appsIconBtn, img);
-	    WMHangData(prefs->appsIconBtn, PLGetString(val));
+	    WMHangData(prefs->appsIconBtn, WMGetFromPLString(val));
 	    free(img);
 	}
     }
@@ -1040,33 +1040,33 @@ static void
 populateTypesFields(FSPreferencesPanel *prefs)
 {
     char       *str   = NULL;
-    proplist_t  val   = NULL;
+    WMPropList*  val   = NULL;
     WMListItem *item  = WMGetListSelectedItem(prefs->typesList);
 
     if(!item)
 	return;
 
     val = FSGetDBObjectForKey(item->clientData, "editor");
-    if (val && PLIsString(val))
-	WMSetTextFieldText(prefs->typesEditTF, PLGetString(val));
+    if (val && WMIsPLString(val))
+	WMSetTextFieldText(prefs->typesEditTF, WMGetFromPLString(val));
     else
 	WMSetTextFieldText(prefs->typesEditTF, "");
 
     val = FSGetDBObjectForKey(item->clientData, "viewer");
-    if (val && PLIsString(val))
-	WMSetTextFieldText(prefs->typesViewTF, PLGetString(val));
+    if (val && WMIsPLString(val))
+	WMSetTextFieldText(prefs->typesViewTF, WMGetFromPLString(val));
     else
 	WMSetTextFieldText(prefs->typesViewTF, "");
 
     val = FSGetDBObjectForKey(item->clientData, "icon");
-    if (val && PLIsString(val))
+    if (val && WMIsPLString(val))
     {
-	char *img = LocateImage(PLGetString(val));
+	char *img = LocateImage(WMGetFromPLString(val));
 	
 	if(img)
 	{
 	    FSSetButtonImageFromFile(prefs->typesIconBtn, img);
-	    WMHangData(prefs->typesIconBtn, PLGetString(val));
+	    WMHangData(prefs->typesIconBtn, WMGetFromPLString(val));
 	    free(img);
 	}
     }
@@ -1264,7 +1264,7 @@ genericButtonActionHandler(WMWidget *self, void *clientData)
 	char *appStr     = WMGetTextFieldText(prefs->appsExecTF);
 	char *imgStr     = WMGetHangedData(prefs->appsIconBtn);
 	WMListItem *item = WMGetListSelectedItem(prefs->appsList);
-	proplist_t array = WMGetUDObjectForKey(defaultsDB, "EXE");
+	WMPropList* array = WMGetUDObjectForKey(defaultsDB, "EXE");
 
 
 	if(!item)
@@ -1272,20 +1272,20 @@ genericButtonActionHandler(WMWidget *self, void *clientData)
 
 	if(appStr)
 	{
-	    PLInsertDictionaryEntry(item->clientData, 
-				    PLMakeString("exec"), 
-				    PLMakeString(appStr));
+	    WMPutInPLDictionary(item->clientData, 
+				    WMCreatePLString("exec"), 
+				    WMCreatePLString(appStr));
 	}
 	if(imgStr)
 	{
-	    PLInsertDictionaryEntry(item->clientData, 
-				    PLMakeString("icon"), 
-				    PLMakeString(imgStr));
+	    WMPutInPLDictionary(item->clientData, 
+				    WMCreatePLString("icon"), 
+				    WMCreatePLString(imgStr));
 	}
 
-	if(array && PLIsArray(array))
+	if(array && WMIsPLArray(array))
 	{
-	    InsertArrayElement(array, PLMakeString(item->text));
+	    InsertArrayElement(array, WMCreatePLString(item->text));
 	}
 
 	edited = True;
@@ -1318,34 +1318,34 @@ genericButtonActionHandler(WMWidget *self, void *clientData)
 	char *editStr    = WMGetTextFieldText(prefs->typesEditTF);
 	char *imgStr     = WMGetHangedData(prefs->typesIconBtn);
 	WMListItem *item = WMGetListSelectedItem(prefs->typesList);
-	proplist_t array = WMGetUDObjectForKey(defaultsDB, "EXTN");
+	WMPropList* array = WMGetUDObjectForKey(defaultsDB, "EXTN");
 
 	if(!item)
 	    return;
 
 	if(viewStr)
 	{
-	    PLInsertDictionaryEntry(item->clientData, 
-				    PLMakeString("viewer"), 
-				    PLMakeString(viewStr));
+	    WMPutInPLDictionary(item->clientData, 
+				    WMCreatePLString("viewer"), 
+				    WMCreatePLString(viewStr));
 	}
 
 	if(editStr)
 	{
-	    PLInsertDictionaryEntry(item->clientData, 
-				    PLMakeString("editor"), 
-				    PLMakeString(editStr));
+	    WMPutInPLDictionary(item->clientData, 
+				    WMCreatePLString("editor"), 
+				    WMCreatePLString(editStr));
 	}
 	if(imgStr)
 	{
-	    PLInsertDictionaryEntry(item->clientData, 
-				    PLMakeString("icon"), 
-				    PLMakeString(imgStr));
+	    WMPutInPLDictionary(item->clientData, 
+				    WMCreatePLString("icon"), 
+				    WMCreatePLString(imgStr));
 	}
 
-	if(array && PLIsArray(array))
+	if(array && WMIsPLArray(array))
 	{
-	    InsertArrayElement(array, PLMakeString(item->text));
+	    InsertArrayElement(array, WMCreatePLString(item->text));
 	}
 
 	edited = True;
@@ -1376,17 +1376,17 @@ genericButtonActionHandler(WMWidget *self, void *clientData)
     {
 	char *img = NULL;
 	char *tmp = NULL;
-	proplist_t val;
+	WMPropList* val;
 	WMListItem *item = WMGetListSelectedItem(prefs->appsList);
 
 	if(!item || !item->clientData)
 	    return;
 
 	val = FSGetDBObjectForKey(item->clientData, "icon");
-	if (val && PLIsString(val))
+	if (val && WMIsPLString(val))
 	{
 	    tmp = FSRunSelectIconPanel(prefs->win, "Icon Select",
-				       PLGetString(val));
+				       WMGetFromPLString(val));
 	    if(tmp == NULL)
 		return;
 	    
@@ -1405,17 +1405,17 @@ genericButtonActionHandler(WMWidget *self, void *clientData)
     {
 	char *img = NULL;
 	char *tmp = NULL;
-	proplist_t val;
+	WMPropList* val;
 	WMListItem *item = WMGetListSelectedItem(prefs->typesList);
 
 	if(!item || !item->clientData)
 	    return;
 
 	val = FSGetDBObjectForKey(item->clientData, "icon");
-	if (val && PLIsString(val))
+	if (val && WMIsPLString(val))
 	{
 	    tmp = FSRunSelectIconPanel(prefs->win, "Icon Select",
-				       PLGetString(val));
+				       WMGetFromPLString(val));
 	    if(tmp == NULL)
 		return;
 	    
@@ -1791,8 +1791,8 @@ saveAppsTab(FSPreferencesPanel *prefs)
     int row = -1;
     int numRows = -1;
     WMListItem *item = NULL;
-    proplist_t exeArray = WMGetUDObjectForKey(defaultsDB, "EXE");
-    proplist_t extnArray = WMGetUDObjectForKey(defaultsDB, "EXTN");
+    WMPropList* exeArray = WMGetUDObjectForKey(defaultsDB, "EXE");
+    WMPropList* extnArray = WMGetUDObjectForKey(defaultsDB, "EXTN");
 
 
     numRows = WMGetListNumberOfRows(prefs->appsList);
@@ -1804,9 +1804,9 @@ saveAppsTab(FSPreferencesPanel *prefs)
 	    WMSetUDObjectForKey(defaultsDB, item->clientData, item->text);
 	else
 	{
-	    if(exeArray && PLIsArray(exeArray))
+	    if(exeArray && WMIsPLArray(exeArray))
 	    {
-		FSRemoveArrayElement(exeArray, PLMakeString(item->text));
+		FSRemoveArrayElement(exeArray, WMCreatePLString(item->text));
 		WMRemoveUDObjectForKey(defaultsDB, item->text);
 	    }
 	}
@@ -1820,9 +1820,9 @@ saveAppsTab(FSPreferencesPanel *prefs)
 	    WMSetUDObjectForKey(defaultsDB, item->clientData, item->text);
 	else
 	{
-	    if(extnArray && PLIsArray(extnArray))
+	    if(extnArray && WMIsPLArray(extnArray))
 	    {
-		FSRemoveArrayElement(extnArray, PLMakeString(item->text));
+		FSRemoveArrayElement(extnArray, WMCreatePLString(item->text));
 		WMRemoveUDObjectForKey(defaultsDB, item->text);
 	    }
 	}
@@ -1836,11 +1836,11 @@ saveDiscsTab(FSPreferencesPanel *prefs)
     int row = -1;
     int numRows = -1;
     WMListItem *item = NULL;
-    proplist_t array = NULL;
-    proplist_t diskArray = NULL;
+    WMPropList* array = NULL;
+    WMPropList* diskArray = NULL;
     Disc *disk = NULL;
 
-    diskArray = PLMakeArrayFromElements(NULL, NULL);
+    diskArray = WMCreatePLArray(NULL, NULL);
 
     numRows = WMGetListNumberOfRows(prefs->disksList);
     for(row = 0; row < numRows; row++)
@@ -1850,15 +1850,15 @@ saveDiscsTab(FSPreferencesPanel *prefs)
 
 	if(item)
 	{
-	    array = PLMakeArrayFromElements( PLMakeString(disk->name), 
-					     PLMakeString(disk->point), 
-					     PLMakeString(disk->device),
-					     PLMakeString(disk->mnt),
-					     PLMakeString(disk->umnt),
-					     PLMakeString(disk->eject),
-					     PLMakeString(disk->close),
-					     NULL );
-	    PLAppendArrayElement(diskArray, array);
+	    array = WMCreatePLArray( WMCreatePLString(disk->name), 
+				     WMCreatePLString(disk->point), 
+				     WMCreatePLString(disk->device),
+				     WMCreatePLString(disk->mnt),
+				     WMCreatePLString(disk->umnt),
+				     WMCreatePLString(disk->eject),
+				     WMCreatePLString(disk->close),
+				     NULL );
+	    WMAddToPLArray(diskArray, array);
 	}
     }
     WMSetUDObjectForKey(defaultsDB, diskArray, "DISCS");
