@@ -19,7 +19,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include <wraster.h>
 #include <X11/cursorfont.h>
 
@@ -424,17 +424,17 @@ LocateImage(char *name)
     }
     
     /* Uncomment if you want the app to support GIF or JPEG icons */
-/*     if(FSImageTypeIsSupported("GIF")) */
-/*     { */
-/* 	sprintf(tmp, "%s.gif", name); */
-/* 	path = WMPathForResourceOfType(tmp, "gif"); */
-/*     } */
-    
-/*     if(FSImageTypeIsSupported("JPEG")) */
-/*     { */
-/* 	sprintf(tmp, "%s.jpg", name); */
-/* 	path = WMPathForResourceOfType(tmp, "jpg"); */
-/*     } */
+     if(FSImageTypeIsSupported("GIF")) 
+     { 
+ 	sprintf(tmp, "%s.gif", name); 
+ 	path = WMPathForResourceOfType(tmp, "gif"); 
+     }
+  
+     if(FSImageTypeIsSupported("JPEG"))
+     {
+ 	sprintf(tmp, "%s.jpg", name);
+ 	path = WMPathForResourceOfType(tmp, "jpg");
+     } 
         
     if(!path)
     {
@@ -486,7 +486,7 @@ FSParseExecString(char *pathname, char *execStr, ...)
 	switch(*execStr) 
 	{
 	case 's':
-	    (void)va_arg(ap, char);
+	    (void)va_arg(ap, int);
 	    
 	    buffer = (char *) wrealloc(buffer, initBufferSize+cnt+pathnameLen);
 	    str = buffer;
@@ -736,16 +736,18 @@ FSLoadIconPaths(WMList *list)
     int i;
     char mbuf[MAX_LEN];
     char *path;
-    proplist_t pathList, val, WindowMakerDB;
+    WMPropList* pathList;
+    WMPropList* val;
+    WMPropList* WindowMakerDB;
 
     path = wdefaultspathfordomain("WindowMaker");
     
-    WindowMakerDB = PLGetProplistWithPath(path);
+    WindowMakerDB = WMReadPropListFromFile(path);
     if (WindowMakerDB) 
     {
-	if (!PLIsDictionary(WindowMakerDB)) 
+	if (!WMIsPLDictionary(WindowMakerDB)) 
 	{
-	    PLRelease(WindowMakerDB);
+	    WMReleasePropList(WindowMakerDB);
 	    pathList = NULL;
 	    snprintf(mbuf, MAX_LEN, "Window Maker domain (%s) is corrupted!", 
 		     path);
@@ -761,13 +763,13 @@ FSLoadIconPaths(WMList *list)
 			mbuf, "OK", NULL, NULL);
     }
 
-    pathList = PLGetDictionaryEntry(WindowMakerDB, PLMakeString("IconPath"));
-    if (pathList && PLIsArray(pathList)) 
+    pathList = WMGetFromPLDictionary(WindowMakerDB, WMCreatePLString("IconPath"));
+    if (pathList && WMIsPLArray(pathList)) 
     {
-	for (i=0; i<PLGetNumberOfElements(pathList); i++) 
+	for (i=0; i<WMGetPropListItemCount(pathList); i++) 
 	{
-	    val = PLGetArrayElement(pathList, i);
-	    WMAddListItem(list, PLGetString(val));
+	    val = WMGetFromPLArray(pathList, i);
+	    WMAddListItem(list, WMGetFromPLString(val));
 	}
     }
 
