@@ -11,8 +11,8 @@
 #include <errno.h>
 #include <dirent.h>
 #include <stdarg.h>
-#include <WINGs.h>
-#include <WUtil.h>
+#include <WINGs/WINGs.h>
+#include <WINGs/WUtil.h>
 
 #include "FSViewer.h"
 #include "FSUtils.h"
@@ -377,7 +377,7 @@ char *GetFileAbbrev(char *fileName)
 
 char* GetFileImgName(char *fileName, enum FileType fileType)
 {
-    proplist_t dict, value = NULL;
+    WMPropList *dict, *value = NULL;
     char *extn = NULL;
     char *icon = NULL;
     char *name = NULL;
@@ -421,38 +421,6 @@ char* GetFileImgName(char *fileName, enum FileType fileType)
 	return icon;
     else
 	return wstrdup(DEFAULT_STR);
-
-/*     dict = PLGetDictionaryEntry(filesDB, PLMakeString(extn)); */
-/*     if(dict && PLIsDictionary(dict)) */
-/*     { */
-/* 	value = PLGetDictionaryEntry(dict, PLMakeString("icon")); */
-/*     } */
-
-/*     if(value == NULL) */
-/*     { */
-/* 	if(fileType == DIRECTORY) */
-/* 	    value = PLGetDictionaryEntry(filesDB, PLMakeString(DIR_STR)); */
-/* 	else if(fileType == ROOT) */
-/* 	    value = PLGetDictionaryEntry(filesDB, PLMakeString(ROOT_STR)); */
-/* 	else if(fileType == HOME) */
-/* 	    value = PLGetDictionaryEntry(filesDB, PLMakeString(HOME_STR)); */
-/* 	else */
-/* 	{ */
-/* 	    value = PLGetDictionaryEntry(filesDB, PLMakeString(DEFAULT_STR)); */
-/* 	} */
-/*     }	     */
-    
-/*     if(extn) */
-/* 	free(extn); */
-
-     /* No Icons at all!! */
-/*     if(value == NULL) */
-/*     { */
-/* 	return DEFAULT_STR; */
-/*     } */
-
-/*     return PLGetString(value); */
-
 }
 
 char* 
