@@ -19,7 +19,7 @@
 /* Header Files **************************************************************/
 
 #include <X11/xpm.h>
-#include <WINGsP.h>
+#include <WINGs/WINGsP.h>
 #include "timestampWidget.h"
 #include "xpm/clk.xpm"
 #include "xpm/led.xpm"
@@ -880,7 +880,7 @@ static void willResizeTimeStamp(W_ViewDelegate *self, WMView *view,
 	Errors: 	None known.
 
 ******************************************************************************/
-void SetTimeStampBlank(TimeStamp *timestamp, BOOL blank)
+void SetTimeStampBlank(TimeStamp *timestamp, int blank)
 {
     unsigned int Blank;
 
@@ -995,7 +995,7 @@ void SetTimeStampWithTimeTM(TimeStamp *timestamp, struct tm *time)
 	Errors: 	None known.
 
 ******************************************************************************/
-void SetTwentyFour(TimeStamp *timestamp, BOOL twentyfour)
+void SetTwentyFour(TimeStamp *timestamp, int twentyfour)
 {
     CHECK_CLASS(timestamp, timeStampWidgetClass);
 
