@@ -20,10 +20,9 @@
 
 /* Header Files **************************************************************/
 
-#include <WINGs.h>
+#include <WINGs/WINGs.h>
 #include <time.h>
-
-
+/* #include <proplist.h> */
 
 
 /* Definitions ***************************************************************/
@@ -43,15 +42,10 @@ typedef struct  W_TimeStamp TimeStamp;
 
 /* Function Prototypes - timestampWidget.c ***********************************/
 
-extern  W_Class     InitTimeStamp(WMScreen*);
-extern  TimeStamp   *CreateTimeStamp(WMWidget*);
-extern  void        SetTimeStampBlank(TimeStamp*, BOOL);
-extern  void        SetTimeStampWithTimeT(TimeStamp*, time_t);
-extern  void        SetTimeStampWithTimeTM(TimeStamp*, struct tm*);
-extern  void        SetTwentyFour(TimeStamp*, BOOL);
-
-
-
+extern void SetTimeStampBlank(TimeStamp *timestamp, int blank);
+extern void SetTimeStampWithTimeT(TimeStamp *timestamp, time_t time);
+extern void SetTimeStampWithTimeTM(TimeStamp *timestamp, struct tm *time);
+extern void SetTwentyFour(TimeStamp *timestamp, int twentyfour);
 
 /* End Of File - timestampWidget.h *******************************************/
 #endif
